@@ -58,10 +58,10 @@ class EMR_EKSStack(Stack):
         })
 
         # Fargate profile 
-        fgprofile = container.eks.FargateProfile(self, "SparkFargateProfile", cluster=self.cluster, 
-            selectors=[container.eks.Selector(namespace=self.emr_namespace_fg)]
-        )
-        self.cluster.add_fargate_profile("SparkFargateProfile", [container.eks.Selector(namespace=self.emr_namespace_fg)], fargate_profile_name="SparkFargateProfile")
+        # fgprofile = container.eks.FargateProfile(self, "SparkFargateProfile", cluster=self.cluster, 
+        #     selectors=[container.eks.Selector(namespace=self.emr_namespace_fg)]
+        # ) 
+
 
         # Create k8s cluster role for EMR
         emrrole = self.cluster.add_manifest("emrrole", {
